@@ -4,10 +4,6 @@
 
 export conda_pkgs="python=${PYTHON_VERSION} pip cython pytest gmp mpfr"
 
-if [[ "${WITH_SYMPY}" != "no" ]]; then
-    export conda_pkgs="${conda_pkgs} sympy";
-fi
-
 if [[ "${WITH_NUMPY}" != "no" ]]; then
     export conda_pkgs="${conda_pkgs} numpy";
 fi
@@ -16,6 +12,10 @@ if [[ "${WITH_SCIPY}" == "yes" ]]; then
     export conda_pkgs="${conda_pkgs} scipy";
 fi
 
+if [[ "${WITH_DOCS}" == "yes" ]]; then
+    export conda_pkgs="${conda_pkgs} sphinx recommonmark";
+fi
+
 if [[ "${WITH_SAGE}" == "yes" ]]; then
     # This is split to avoid the 10 minute limit
     conda install -q sagelib=8.1
@@ -24,5 +24,10 @@ if [[ "${WITH_SAGE}" == "yes" ]]; then
 fi
 
 conda install -q ${conda_pkgs}
+
+if [[ "${WITH_SYMPY}" != "no" ]]; then
+    pip install sympy;
+fi
+
 conda clean --all
 source activate $our_install_dir;
